#ifndef TRANSFORMATIONS_H_
#define TRANSFORMATIONS_H_


/*-------------Data structures utilized for three-phase magnitude transformations----------------
 * --------------------------------------------------------------------------------------------*/


/* Physical values of a three-phase magnitude in time domain */
typedef struct{
	float32 A;
	float32 B;
	float32 C;
} TimeDomain;

/* Real, imaginary and homopolar parts of a phasor in stationary (AlphaBeta0) or rotating (DQ0) reference frame */
typedef struct{
	float32 real;
	float32 imaginary;
	float32 homopolar;
} SpacePhasor;


/*---------------------------------Transformation Function Prototypes-----------------------------------------------
 * -----------------------------------------------------------------------------------------------------------*/


/* Transformation from physical (ABC) to stationary (Alphabeta) reference frame */
void ABC2AlphaBeta(SpacePhasor *fixed, const TimeDomain *physical);

/* Transformation from stationary (AlphaBeta) to physical (ABC) reference frame */
void AlphaBeta2ABC(TimeDomain *physical, const SpacePhasor *fixed);

/* Transformation from stationary (AlphaBeta) to rotating (DQ) reference frame */
void AlphaBeta2DQ(SpacePhasor *rotating, const SpacePhasor *fixed, const float32 theta);

/* Transformation from rotating (DQ) to stationary (Alphabeta) reference frame */
void DQ2AlphaBeta(SpacePhasor *fixed, const SpacePhasor *rotating, const float32 theta);

/* Transformation from physical (ABC) to rotating (DQ) reference frame */
void ABC2DQ(SpacePhasor *rotating, const TimeDomain *physical, const float32 theta);

/* Transformation from rotating (DQ) to physical (ABC) reference frame */
void DQ2ABC(TimeDomain *physical, const SpacePhasor *rotating, const float32 theta);


#endif /*TRANSFORMATIONS_H_*/
