#ifndef MACROS_H_
#define MACROS_H_

#include "DSP28x_Project.h"				// Headers for C28346


/*
 * Pre-computed general constants
 * These constants are used in order to make the online computations faster
 */
#define FPGA_WDR_PERIOD 0x0F		// Maximum reset period of FPGA's watchdog
									// max	0x0F : 160us
									// min  0x02 : 3us


/*
 * Useful generic definitions
 */
#define Uint16_max 65535
#define Uint16_min 0
#define Int16_max 32767
#define Int16_min -32768

#define Uint14_max 16383
#define Uint14_min 0
#define Int14_max 8191
#define Int14_min -8192

#define Uint12_max 4095
#define Uint12_min 0
#define Int12_max 2047
#define Int12_min -2048


#define RISING 1
#define FALLING 0

/*
 * Useful macros
 */

#define max(a,b)				(a>b ? a : b)
#define min(a,b)				(a>b ? b : a)
#define sign(a)					(a>0 ? 1 : 0)

#define _reset();               EALLOW; \
								asm ("      ESTOP0"); \
								SysCtrlRegs.PLLSTS.bit.DIVSEL = 0; \
								SysCtrlRegs.PLLCR.bit.DIV = 0; \
								SysCtrlRegs.WDCR = 0x0000; \
								EDIS; \
								while(1);
								// reset device
								// ESTOP0 : breakpoint for the emulator
								//          (equivalent as nop if standalone)
								// Reset the PLL (sysclk 300M to 10M)
								//			THIS IS REQUIRED BY THE BOOTLOADER
								// Ask the watchdog module for a reset.
								// Wait.
								//
								// needs

// Assembly macro functions (defined in lowlev.asm);

/**
 * Gets the contents of IFR (interrupt flag register)
 * Assembly function. (cannot do it in C)
 * @param void
 * @return unsigned short int IFR contents
 */
extern unsigned short int getIFR(void);

/**
 * Gets the contents of SP (stack pointer)
 * Assembly function. (cannot do it in C)
 * @param void
 * @return unsigned short int SP contents
 */
extern unsigned short int getSP(void);


/**
 * Provides a conversion from an Uint16 to its human-readable binary value
 * "0bxxxx xxxx xxxx xxxx"
 * @param unsigned short int myreg
 * @return char* pointer to the converted string
 */
char* Uint16_to_BinaryASCII(unsigned short int myreg);

/**
 * Provides a conversion from an Uint16 to its human-readable hexadecimal value
 * "0xXXXX"
 * @param unsigned short int myreg
 * @return char* pointer to the converted string
 */
char* Uint16_to_HexASCII(unsigned short int myreg);



#endif /*MACROS_H_*/
