/*------------------------------------------------------------------
 * cli.h -- command line interpreter
 *
 * Base from project eCLI,  (c) 2009 by B. Berry
 * http://ecli.sourceforge.net/
 *
 * Modified and improved for BoomBox project in order to enable
 * dynamic memory allocation by S. Delalay
 * <simon.delalay@epfl.ch>
 *------------------------------------------------------------------
 */

#ifndef __CLI_H__
#define __CLI_H__

#include "DSP28x_Project.h"					// Headers for C28346


/*
 * This is the maximum number of parameters that can be passed
 * to the application function.  The parameters are passed to
 * the application in the argument count and argument value
 * format.
 */
#define ARGC_MAX    ( 10 )


/*
 * Number of characters in an entry's name, for directories
 * and commands
 */
#define CLI_ENTRY_LEN    ( 34 )


/*
 * return codes
 */
typedef enum {
    RC_CLI_OK = 0,
    RC_CLI_NULL_NAME,
    RC_CLI_NULL_FV,
    RC_CLI_DUPLICATE,
    RC_CLI_RECORD_CORRUPT,
    RC_CLI_NULL_CMD,
    RC_CLI_DIR_INVALID
} CLI_RESPONSE_t;



/*
 * type def for call back function to process user command parsers
 */
typedef void (*cli_funcvar_t)(unsigned int argc, char *argv[]);


/*
 * The structure for a directory or command entry.
 */
typedef struct t_nodal_record {
    struct t_nodal_record  *cmd_list;
    char                   name[CLI_ENTRY_LEN+1];
    cli_funcvar_t          fv;
    struct t_nodal_record  *parent_dir;
    struct t_nodal_record  *next_entry;
    struct t_nodal_record  *link2subdir;
} cli_record_t;



/*
 * The structure required to initialize the CLI facility.
 * It must be initialized before use.
 */
typedef struct {
    char  prefix[CLI_ENTRY_LEN];
} cli_init_data_t;



/*
 * prototypes
 */

/* String comparator
 *
 */
extern Uint16 str_exact (char *p1, char *p2);

/* add a command */
extern CLI_RESPONSE_t fs_mkcmd (char *name, char *parent, cli_funcvar_t fv);
extern CLI_RESPONSE_t fs_mkcmd_user (char *name, cli_funcvar_t fv);

/* make a directory */
extern CLI_RESPONSE_t fs_mkdir(char *name, char *parent);


/* drive the cli */
extern void cli_engine(char *input_string);


/* set the prompt string */
void cli_update_prompt(void );


/* init function */
extern CLI_RESPONSE_t cli_init(cli_init_data_t *init_data);

#endif  /*  __CLI_H__  */

