/*
 * scib_driver.h
 *
 *  Created on: 22 juin 2011
 *      Author: delalay
 */

#ifndef SCIB_DRIVER_H_
#define SCIB_DRIVER_H_
#include <file.h>

#if (!CPU_FRQ_300MHZ)
	#error "SYSCLKOUT shout be at 300MHz for correct UART operation"
#endif


/** This function finds a file matching path and opens it for I/O as requested by flags.
 *
 * @param path 		the filename of the file to be opened
 * @param flags 	flags are attributes that specify how the file is manipulated
 *              	see p1. 159 of TI's doc SPRU514D
 * @param lld_fv 	suggested low-level file descriptor. This is a historical artifact. Not used.
 * @return 			-1 to indicate an error if for some reason the file could not be opened
 *         			On success, this function returns a non-negative file descriptor
 *         			unique among all open files handled by the specific device
 */
int ScibDriver_Open(const char *path, unsigned flags, int llv_fd);

/** This function closes a valid open file descriptor.
 * @param dev_fd 	A valid file descriptor.
 * @return 			-1 If error. Otherwise a file descriptor positive number unique.
 */
int ScibDriver_Close(int dev_fd);

/** The read function reads count bytes from the input file associated with dev_fd.
 * @param dev_fd 	A valid file descriptor
 * @param buf		where the read characters are placed
 * @param count		the number of characters to read from the file
 * @return 			-1 to indicate an error. Otherwise the number of bytes read, from 0 to count
 */
int ScibDriver_Read(int dev_fd, char *buf, unsigned count);

/** This function writes count bytes to the output file
 * @param dev_fd 	A valid file descriptor
 * @param buf		where the write chars are placed
 * @param count		the number of characters to write to the file
 * @return 			-1 to indicate an error.
 */
int ScibDriver_Write(int dev_fd, const char *buf, unsigned count);


/** Set File Position Indicator. NOT AVAILABLE FOR THSI DRIVER
 * This function sets the file's position indicator for this file descriptor as lseek.
 * @return 			-1 to indicate an error.
 */
off_t ScibDriver_lseek(int dev_fd, off_t offset, int origin);

/**  Remove the association of the pathname with the file. NOT AVAILABLE FOR THSI DRIVER
 * @return 			-1 to indicate an error.
 */
int ScibDriver_unlink(const char *path);

/** This function changes the name associated with the file. NOT AVAILABLE FOR THSI DRIVER
 * @return 			-1 to indicate an error.
 */
int ScibDriver_rename(const char *old, const char *new);

#endif /* SCIB_DRIVER_H_ */
