#ifndef IRQ_H_
#define IRQ_H_


/**
 * Possible interrupt sources for both IRQ sources
 */
typedef enum {
	NONE		=0,
	ACQ			=1*16+0,

	PWM0		=2*16+0,
	PWM1		=2*16+1,
	PWM2		=2*16+2,
	PWM3		=2*16+3,

	GPI0		=3*16+0,
	GPI1		=3*16+1,
	GPI2		=3*16+2,
	GPI3		=3*16+3,
	GPI4		=3*16+4,
	GPI5		=3*16+5,
	GPI6		=3*16+6,
	GPI7		=3*16+7,
} IRQ_SOURCES ;

/**
 * Routine for the initialization of the interrupt sources to their default values
 * Both sources disabled
 */
void InitAllIRQ();

/**
 * Routine to configure the first interrupt source to the desired peripheral
 * @param source the peripheral that should be used to generate the IRQ
 * @return void
 */
void setIRQ1(IRQ_SOURCES source);


/**
 * Routine to configure the first interrupt source to the desired peripheral
 * @param source the peripheral that should be used to generate the IRQ
 * @return void
 */
void setIRQ2(IRQ_SOURCES source);


#endif /* IRQ_H_ */
