/*
 *  @title    Application related peripherals
 * 	@context  BoomBox & MMC-Box
 *	@author   S. Delalay <simon@delalay.net>
 *	@file     peripherals.c
 */

#include "DSP28x_Project.h"											// Headers for C28346
#include <stdio.h>
#include "hardware.h"												// DSP specific pins and IOs
#include "peripherals.h"											// Peripherals and related hardware configurations
											
											
#ifdef __cplusplus
#pragma DATA_SECTION("dataFPGAs")									// FPGA memory mapping
#else
#pragma DATA_SECTION(XD6,"dataFPGAs");
#endif
volatile struct XINTF6D XD6;


short unsigned int  CheckDaughterBoards(void)
{
	unsigned short int output = 0;
	unsigned short int k = 0;
	while (k<4)
	{
		unsigned int i;
		SelectDaughter(k);
		SpiaRegs.SPITXBUF = SPI_DELFINO_WHO_IS_THERE;				// Send info message
		i = 10;
		while (i--)
		{
			ServiceDog();											// Wait until data is received
			DELAY_US(10);											// Wait while daughterbds prepare the echoback
		}
		SpiaRegs.SPITXBUF = SPI_DELFINO_WHO_IS_THERE;				// Send dummy message in order to read back
		i = 10;
		while (i--)
		{
			ServiceDog(); 											// Wait until data is received
			DELAY_US(10);											// Wait while daughterbds prepare the echoback
		}
		while (SpiaRegs.SPIFFRX.bit.RXFFST) i = SpiaRegs.SPIRXBUF;	// get the last element received
															
		if ((i & 0x00FF) == (SPI_DELFINO_WHO_IS_THERE & 0x00FF))
			output += (0x0001 << k);
		k++;
	}
	return output;
}
void InitSPI()
{

   EALLOW;
/* Enable internal pull-up for the selected pins */
// Pull-ups can be enabled or disabled by the user.
// This will enable the pullups for the specified pins.
// Comment out other unwanted lines.

    GpioCtrlRegs.GPAPUD.bit.GPIO16 = 0;								// Enable pull-up on GPIO16 (SPISIMOA)
    GpioCtrlRegs.GPAPUD.bit.GPIO17 = 0;								// Enable pull-up on GPIO17 (SPISOMIA)
    GpioCtrlRegs.GPAPUD.bit.GPIO18 = 0;								// Enable pull-up on GPIO18 (SPICLKA)
    GpioCtrlRegs.GPAPUD.bit.GPIO19 = 0;								// Enable pull-up on GPIO19 (SPISTEA)



/* Set qualification for selected pins to asynch only */
// This will select asynch (no qualification) for the selected pins.
// Comment out other unwanted lines.

    GpioCtrlRegs.GPAQSEL2.bit.GPIO16 = 3;							// Asynch input GPIO16 (SPISIMOA)
    GpioCtrlRegs.GPAQSEL2.bit.GPIO17 = 3;							// Asynch input GPIO17 (SPISOMIA)
    GpioCtrlRegs.GPAQSEL2.bit.GPIO18 = 3;							// Asynch input GPIO18 (SPICLKA)
    GpioCtrlRegs.GPAQSEL2.bit.GPIO19 = 3;							// Asynch input GPIO19 (SPISTEA)



/* Configure SPI-A pins using GPIO regs*/
// This specifies which of the possible GPIO pins will be SPI functional pins.
// Comment out other unwanted lines.

    GpioCtrlRegs.GPAMUX2.bit.GPIO16 = 1;							// Configure GPIO16 as SPISIMOA
    GpioCtrlRegs.GPAMUX2.bit.GPIO17 = 1;							// Configure GPIO17 as SPISOMIA
    GpioCtrlRegs.GPAMUX2.bit.GPIO18 = 1;							// Configure GPIO18 as SPICLKA
	// GpioCtrlRegs.GPAMUX2.bit.GPIO19 = 1; // Configure GPIO19 as SPISTEA // NO! Hardware error.
	// Instead, SPISTEA is tied to VCC.
    GpioCtrlRegs.GPADIR.bit.GPIO19 = 1; 							// Output
    GpioDataRegs.GPADAT.bit.GPIO19 = 1; 							// VCC



    SelectDaughter(0); 												// Address selector at 0;

	// Initialize SPI FIFO registers
	SpiaRegs.SPIFFTX.all=0xE040;
	SpiaRegs.SPIFFRX.all=0x204f;
	SpiaRegs.SPIFFCT.all=0x0;

	// Initialize SPI
    SpiaRegs.SPICCR.all =0x0007;	             					// Reset on, rising edge, 16-bit char bits
    SpiaRegs.SPICTL.all =0x0006;    		     					// Enable master mode, normal phase,
                                                 					// enable talk, and SPI int disabled.
    // SpiaRegs.SPIBRR =0x007F;
    SpiaRegs.SPIBRR =0x000A;
    SpiaRegs.SPICCR.all =0x0087;									// Relinquish SPI from Reset
    SpiaRegs.SPIPRI.bit.FREE = 1;									// Set so breakpoints don't disturb xmission

    EDIS;
}
/*
 * Enables the communication with a daughterboard through I2C and SPI
 * Actually configures the address decoder
 */
void SelectDaughter(short unsigned int id)
{
    GpioCtrlRegs.GPADIR.bit.GPIO25 = 1;								// Direction is output
    GpioCtrlRegs.GPADIR.bit.GPIO26 = 1;								// Direction is output
    GpioCtrlRegs.GPADIR.bit.GPIO27 = 1;								// Direction is output

	switch(id)
	{
	case 0 : 	    GpioDataRegs.GPACLEAR.bit.GPIO25 = 1;
    				GpioDataRegs.GPACLEAR.bit.GPIO26 = 1;
    				GpioDataRegs.GPACLEAR.bit.GPIO27 = 1;
    				break;
	case 1 : 		GpioDataRegs.GPACLEAR.bit.GPIO25 = 1;
    				GpioDataRegs.GPASET.bit.GPIO26 = 1;
    				GpioDataRegs.GPACLEAR.bit.GPIO27 = 1;
    				break;
	case 2 : 	    GpioDataRegs.GPACLEAR.bit.GPIO25 = 1;
					GpioDataRegs.GPACLEAR.bit.GPIO26 = 1;
					GpioDataRegs.GPASET.bit.GPIO27 = 1;
					break;
	case 3 : 		GpioDataRegs.GPACLEAR.bit.GPIO25 = 1;
					GpioDataRegs.GPASET.bit.GPIO26 = 1;
					GpioDataRegs.GPASET.bit.GPIO27 = 1;
					break;
	default : 		break;
	}
	//DELAY_US(5);	// Wait 5 us. (activation of Multia SPI interface)
}

/**
 * Initialization of the XTINF module for FPGA communication using zone 6
 */
void InitXINTF(void){
	EALLOW;
    	SysCtrlRegs.PCLKCR3.bit.XINTFENCLK = 1;
    EDIS;

    // Configure the GPIO for XINTF with a 32-bit data bus
    InitXintf32Gpio();


    // Configure GPIO28 for XZCS6
    GpioCtrlRegs.GPAPUD.bit.GPIO28 = 1;
    GpioCtrlRegs.GPADIR.bit.GPIO28 = 1;
    GpioCtrlRegs.GPAQSEL2.bit.GPIO28 = 11;

	
	EALLOW;
    	SysCtrlRegs.PCLKCR3.bit.XINTFENCLK = 1;
    	// Enable the XINTF peripheral clock
    EDIS;
   
    // Parameters for all zones XCLKOUT = 37.5MHz ------
    // Assuming SYSCLKOUT = 300M
    EALLOW;
		// XTIMCLK VS SYSCLKOUT (0=> XTIMCLK = SYSCLKOUT, 1 => XTIMCLK = 1/2 SYSCLKOUT)
	    XintfRegs.XINTCNF2.bit.XTIMCLK = 1;
	    // Write buffering depth = 4
	    XintfRegs.XINTCNF2.bit.WRBUFF = 3;
	    // XCLKOUT VS XTIMCLK (0 => XCLKOUT = XTIMCLK, 1 => XCLKOUT = 1/2 XCLKOUT) in term of frequency
	    XintfRegs.XINTCNF2.bit.CLKMODE = 1;
	    // 1 => XCLKOUT = XTIMCLK/4 (SYSCLKOUT/4),  0 => XCLKOUT = XTIMCLK
	    XintfRegs.XINTCNF2.bit.BY4CLKMODE = 0;
	    // 0 => CLKOUT available outside (pin 163), 1 => CLKOUT not available outside
	    XintfRegs.XINTCNF2.bit.CLKOFF = 0;
	    
    // Zone 6------------------------------------
    // When using ready, ACTIVE must be 1 or greater
    // Lead must always be 1 or greater

    XintfRegs.XTIMING6.bit.XWRLEAD = 1;
    XintfRegs.XTIMING6.bit.XWRACTIVE = 2;
    XintfRegs.XTIMING6.bit.XWRTRAIL = 0;

    XintfRegs.XTIMING6.bit.XRDLEAD = 1;
    XintfRegs.XTIMING6.bit.XRDACTIVE = 4;
    XintfRegs.XTIMING6.bit.XRDTRAIL = 0;

    XintfRegs.XTIMING6.bit.X2TIMING = 1;

    // Zone will not sample XREADY signal
    XintfRegs.XTIMING6.bit.USEREADY = 0;
    XintfRegs.XTIMING6.bit.READYMODE = 0;

    // 1,1 = x16 data bus
    // 0,1 = x32 data bus
    // other values are reserved
    XintfRegs.XTIMING6.bit.XSIZE = 3;

	// Zone 7 to do (SRAM on DIMM168)
    // Zone 7------------------------------------
    // When using ready, ACTIVE must be 1 or greater
    // Lead must always be 1 or greater
    // Zone write timing
    XintfRegs.XTIMING7.bit.XWRLEAD = 1;
    XintfRegs.XTIMING7.bit.XWRACTIVE = 3;
    XintfRegs.XTIMING7.bit.XWRTRAIL = 0;
    // Zone read timing (for 12ns memories, always refer to data manual for latest timings)
    XintfRegs.XTIMING7.bit.XRDLEAD = 1;
    XintfRegs.XTIMING7.bit.XRDACTIVE = 4;
    XintfRegs.XTIMING7.bit.XRDTRAIL = 0;

    // Do Not double all Zone read/write lead/active/trail timing
    XintfRegs.XTIMING7.bit.X2TIMING = 1;

    // Zone will not sample XREADY signal
    XintfRegs.XTIMING7.bit.USEREADY = 0;
    XintfRegs.XTIMING7.bit.READYMODE = 0;

    // 1,1 = x16 data bus
    // 0,1 = x32 data bus
    // other values are reserved
    XintfRegs.XTIMING7.bit.XSIZE = 1;
    EDIS;

   //Force a pipeline flush to ensure that the write to
   //the last register configured occurs before returning.
   asm(" RPT #7 || NOP");	// ie 8 times NOP
}

/**
 * Initialization of the SCIB serial port (UART) for computer communication
 */
 void InitSCIB(void) {
	// Init SCIB gpios
	//InitScibGpio();	
	
 	ScibRegs.SCICCR.all =0x0007;									// 1 stop bit,  No loopback
                                   									// No parity,8 char bits,
                                   									// async mode, idle-line protocol
	ScibRegs.SCICTL1.all =0x0003;  									// enable TX, RX, internal SCICLK,
                                   									// Disable RX ERR, SLEEP, TXWAKE
	ScibRegs.SCICTL2.all =0x0003;
	ScibRegs.SCICTL2.bit.TXINTENA =1;
	ScibRegs.SCICTL2.bit.RXBKINTENA =1;
	#if (!CPU_FRQ_300MHZ)
	//#warn "SYSCLKOUT shout be at 300MHz for correct UART operation"
	#endif	
	ScibRegs.SCIHBAUD    =0x0003;  									// 9600 baud @LSPCLK = 75.0MHz.
	ScibRegs.SCILBAUD    =0x00D0;
	
	ScibRegs.SCICTL1.all =0x0023;  									// Relinquish SCI from Reset
}


/**
 * Initializes the I/O mux and I/O direction register
 * in order to use the peripherals correctly (LEDS, system
 * signals,...)
 */
void InitGPIO(void)
{
	// External hardware interrupt trigger signal 1 :
	// This line is used for the XINT1
	EALLOW;
	(GpioCtrlRegs.GPAPUD.bit.GPIO22) = 1;							// Disable pull-up
	(GpioCtrlRegs.GPADIR.bit.GPIO22) = 0;							// Direction is input
	(GpioCtrlRegs.GPAMUX2.bit.GPIO22) = 0;							// IO pin is configured as GPIO
	EDIS;

	// External hardware interrupt trigger signal 2 :
	// This line is used for the XINT2
	EALLOW;
	(GpioCtrlRegs.GPAPUD.bit.GPIO23) = 1;							// Disable pull-up
	(GpioCtrlRegs.GPADIR.bit.GPIO23) = 0;							// Direction is input
	(GpioCtrlRegs.GPAMUX2.bit.GPIO23) = 0;							// IO pin is configured as GPIO
	EDIS;

	// External hardware interrupt trigger signal FAULT :
	// This line is used for the NMI
	EALLOW;
	(GpioCtrlRegs.GPAPUD.bit.GPIO0) = 1;							// Disable pull-up
	(GpioCtrlRegs.GPADIR.bit.GPIO0) = 0;							// Direction is input
	(GpioCtrlRegs.GPAMUX1.bit.GPIO0) = 0;							// IO pin is configured as GPIO
	EDIS;

	// nPWM_HPR signal configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO1 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO1 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO1 = 0;								// IO pin is configured as GPIO
	EDIS;

	// Set the HPR signal to its default value :
	SIG_nHPR = 1;


	// Status FAULT_LED configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO2 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO2 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO2 = 0;								// IO pin is configured as GPIO
	EDIS;

	// Status RUN_LED configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO3 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO3 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO3 = 0;								// IO pin is configured as GPIO
	EDIS;


	// User LED0 Red configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO4 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO4 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO4 = 0;								// IO pin is configured as GPIO
	EDIS;

	// User LED0 Green configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO5 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO5 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO5 = 0;								// IO pin is configured as GPIO
	EDIS;

	// User LED1 Red configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO6 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO6 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO6 = 0;								// IO pin is configured as GPIO
	EDIS;

	// User LED1 Green configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO7 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO7 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO7 = 0;								// IO pin is configured as GPIO
	EDIS;

	// User LED2 Red configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO8 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO8 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO8 = 0;								// IO pin is configured as GPIO
	EDIS;

	// User LED2 Green configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO9 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO9 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO9 = 0;								// IO pin is configured as GPIO
	EDIS;

	// User LED3 Red configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO11 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO11 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO11 = 0;							// IO pin is configured as GPIO
	EDIS;

	// User LED3 Green configuration :
	EALLOW;
	GpioCtrlRegs.GPAPUD.bit.GPIO12 = 1;								// Disable pull-up
	GpioCtrlRegs.GPADIR.bit.GPIO12 = 1;								// Direction is output
	GpioCtrlRegs.GPAMUX1.bit.GPIO12 = 0;							// IO pin is configured as GPIO
	EDIS;

	// Set the user LEDs to their default status (0=off, 1=on) :
	USER_LED0_OFF();
	USER_LED1_OFF();
	USER_LED2_OFF();
	USER_LED3_OFF();
}


/**
 * Starts the watchdog with the given period :
 * 1 -> 1.7usec
 * 2 -> 3.4usec
 * 3 -> 6.82usec
 * 4 -> 13.65usec
 * 5 -> 27.3usec
 * 6 -> 54.6usec
 * 7 -> 109.2usec
 * http://focus.ti.com/general/docs/litabsmultiplefilelist.tsp?literatureNumber=sprufn1b
 * */
void StartDog(Uint16 period)
{
	EALLOW;
	SysCtrlRegs.WDCR = (0x0028 | (period & 0x0007));	// Mandatory write 101 on bits 5-4-3
	EDIS;
}

