#ifndef SOGI3I_H_
#define SOGI3I_H_

/*
 *	Struct holding the state information for a triple integrator. Such a module is used to approximate
 *	1/s in a discrete environment
 */
typedef struct {
	float z1;
	float z2;
	float z3;
	float output;
}IntegratorStates;

/*
 *	All the parameters stored in this struct make up a SOGI module based on the triple integrator
 *	approximation.
 */
typedef struct {
	IntegratorStates states[2];
	float omega;
	float gain;
	float constant;
} SOGI_3I_module;

/*
 * Initialize the SOGI module with default values. SOGI_GAIN, SOGI_CONST and SOGI_OMEGA must be predefined.
 * SOGI_GAIN is the gain value of the SOGI module
 * SOGI_CONST is the sampling time divided by 12
 * SOGI_OMEGA is the expected angle speed of the input signal (feed forward)
 */
void SOGI_init(SOGI_3I_module *module);

/*
 * Update the SOGi module, takes the measurement value as input. function must be run at a
 * frequency of 1/Ts for correct behaviour.
 */
void SOGI_step(SOGI_3I_module *module, float measurement);

#endif /* SOGI3I_H_ */
