#ifndef ADC_FUNCTIONS_H_
#define ADC_FUNCTIONS_H_

#include "mapping.h"				// Definition of the available DSP peripherals

// Define a type ADC_Channel containing 2 corrective parameters
typedef struct{
	float GAIN;
	float OFFSET;
} ADC_Channel;

// Define a type ADC_Module which is a array of a few ADC_Channels
typedef ADC_Channel ADC_Module[QTY_OF_ADC_CHANNELS];


/**
 * Routine for the initialization of all corrective parameters and
 * software limits to their default values
 * @param void
 * @return void
 */
void InitAllADC();

/**
 * Routine for setting the corrective parameters to specific values
 * @param module	which module (daughterboard number) to set
 * @param channel	which channel to set
 * @param gain		new gain value
 * @param offset	new offset value
 * @return 0 if ok, 1 if any error in the channel being addressed
 */
int setADCAdjustments(int module, int channel, float gain, float offset);


/**
 * Getter for ADC data (with FPGA-computed limits)
 * @param module	which module (daughterboard number) to get
 * @param channel	which channel to get
 * @return requested value (float)
 */
float getADC(int module, int channel);


#endif /* ADC_FUNCTIONS_H_ */
