#ifndef PERIPHERALS_H_
#define PERIPHERALS_H_

/**
 * This file defines the peripherals that are available to the application.
 * These definitions are are specific to the BoomBox or the MMC-Box
 */

#include "mapping.h"			// Definition of the available hardware
#include "adc.h"				// ADC module configuration functions
#include "pwm.h"				// FPGA-based PWM control functions
#include "gpo.h"				// FPGA-based GPO
#include "gpi.h"				// FPGA-based GPI
#include "irq.h"				// FPGA-based IRQ generator


/**
 * UART PC communication (baudrate)
 */
//#define UART_BR_9_600
//#define UART_BR_115_200
//#define UART_BR_750_000
#define UART_BR_1_333_333

/**
 * Checks for daugtherboards presence through SPI interface
 */
short unsigned int CheckDaughterBoards(void);

/*
 * Enables the communication with a daugtherboard through I2C and SPI
 * Actually configures the address decoder
 */
void SelectDaughter(short unsigned int id);

/**
 * Serial communication interface init.
 * For communication with daughterboards.
 */
void InitSPI(void);

/**
 * External parallel interface init.
 * Initializes the XTINF in order to communicate
 * with the FPGA
 */
void InitXINTF(void);
 

/**
 * Serial port init.
 * Initializes the serial module SCIB in order 
 * to communicate with the host computer through
 * the serial-to-usb transcriver (FT2232).
 */
void InitSCIB(void);


/**
 * Initializes the I/O mux and I/O direction register
 * in order to use the peripherals correctly (LEDS, system
 * signals,...)
 */
void InitGPIO(void);
 

/**
 * Starts the watchdod with given period :
 * 1 -> 1.7usec
 * 2 -> 3.4usec
 * 3 -> 6.82usec
 * 4 -> 13.65usec
 * 5 -> 27.3usec
 * 6 -> 54.6usec
 * 7 -> 109.2usec
 * http://focus.ti.com/general/docs/litabsmultiplefilelist.tsp?literatureNumber=sprufn1b
 * */
void StartDog(Uint16 period);

#endif /*PERIPHERALS_H_*/
