#ifndef USER_H_
#define USER_H_

#include "Driver/peripherals.h"					// Available DSP peripherals
#include "Core/macros.h"						// Global defines and macros
#include "Core/core.h"							// Core functions
#include "../API/control_functions.h"			// functions used for sogi and pll modules
#include "../My_functions/SOGI3I.h"				// Sogi module
#include "../support_functions.h"				// functions used for open and closed loop regulation


/**
 * Type defining if the the system is safe or not
 */
typedef enum {
	SAFE      = 0,
	UNSAFE    = 1
} USER_SAFE ;

/**
 * Modes of operation for the user-level application
 * These definitions apply to the user's state machine
 */
typedef enum {
	WAITING					=0,
	OPEN_LOOP_CONTROL		=1,
	CLOSED_LOOP_CONTROL		=2,
	CLEAN_UP				=3,
	DEBUG					=4,
	FAULT					=5
} USER_STATE ;

/**
 * Global variables
 * Please pay attention not to define variables that are unnecessarily global !
 */

//STATES FOR STATE MACHINES
extern USER_STATE user_state, next_user_state;
extern SWITCH_STATE switch_state, next_switch_state;

//FLAGS
extern int flagFillBuffer, flagInit, flagPrint;

//extern LPFparameters filter;
extern SOGI_3I_module sogi, sogi_c;
extern PLLparameters pll;
extern float LEM_current, LEM_voltage;
extern float voltage_diff;
extern DutycycleParameters PWM_d;
extern RegulatorParameters current_reg;
extern float currentReference;
extern float altRMS;

/**
 * Does the initialization of user application.
 * This function is called after the initialization of the core.
 * @return SAFE if no error
 */
USER_SAFE UserInit(void);

/**
 * Does the start of user application.
 * This function is called by CoreStart().
 * @return SAFE if no error
 */
USER_SAFE UserStart(void);

/**
 * Does the stop of user application.
 * This function is called by CoreStop().
 * @return SAFE if no error
 */
USER_SAFE UserStop(void);


/**
 * This is the interrupt with the highest priority available to the user.
 * It should contain the main control routines.
 * @param void
 * @return SAFE if no error
 */
USER_SAFE UserInterrupt1(void);


void UserError(int code);

void fillOutputBuffers(int index);
void decodeError(int code);

#endif /*USER_H_*/
