/*
 *  @title    Functions to implement open and closed loop control of an AC Chopper
 * 	@context  BoomBox & MMC-Box
 *	@author   O.C. Spro <ocspro@gmail.com>
 *	@file     support_functions.h
 *	@comment  last updated: 22.07.2013
*/

#ifndef SUPPORT_FUNCTIONS_H_
#define SUPPORT_FUNCTIONS_H_

#include "Driver/adc.h"
#include "Driver/pwm.h"
#include "inc/extern_user.h"

/*
 * Possible switching states according to current and voltage polarity
 */
typedef enum {
	START = 0,
	COMMUTATION_POS = 1,
	COMMUTATION_NEG = 2,
	FREE_WHEEL = 3,
}SWITCH_STATE ;

/*
 * Paramters and state variables for a digital controller
 */
typedef struct{
	float old_output, new_output;
	float old_input [4];
	float parameters[5];
}RegulatorParameters ;

/*
 * Defining possible parameters for an open loop duty cycle
 */
typedef struct{
	float bias;
	float amplitude;
	int frequency;
	double phase_shift;
}DutycycleParameters;


void switchingControl();
float runRegulator(RegulatorParameters *reg, float error); //returns new duty cycle
void initRegulator(RegulatorParameters *reg);

//switch setups
void setSwitchComPos();
void setSwitchComNeg();
void setSwitchFW();
void setSwitchOff();

int checkVoltagePolarity();
//int checkCurrentDirection();

int checkVoltageOverThreshold();
int checkVoltageUnderThreshold();
int checkZeroCurrent();

void sampleSensors();
float calculateDutycycle();


#endif /* SUPPORT_FUNCTIONS_H_ */
