clc;
clear all;

%% Parameters

%simulation parameter
sim_time = 2;
sim_maxstep = 1e-3;

%grid parameters:
Uline = 1 * sqrt(2) / sqrt(3);		%grid line voltage
fnet = 16 + 2/3;					%grid frequency
wnet = 2* pi * fnet;				%grid angle speed

%per unit parameters:
Unom = 400;
Inom = 1e3;
Snom = Unom * Inom;
Znom = Unom^2 / Snom;

%ciruit parameters:
Ra = 1e-3;							%load resistance
La = 470e-6;						%load inductance
Ca = 21e-3;							%load capacitance

ra = Ra * Inom / Unom;				%load resistance in p.u.
la = La * Inom / Unom;				%load inductance in p.u.
ca = Ca * Inom / Unom;				%load capacitance in p.u.

%PWM parameters:
fsw = 4e3;							%switching frequency
Tp = 1/fsw;							%switching period
Tcm = Tp / 3;						%PWM delay
switching_threshold = 0.00;

%regulator paramters;
Kp_d = 0.07;
Ti_d = 0.02;
Kp_q = 0.2;
Ti_q = 0.03;

%% references:
i_d_ref = 1;
i_q_ref = -0.1286;

%% Simulation

sim('Chopper_continousswitch_closedloop')

%% Plotting
close all;

figure;
plot(t, u_source, t, i_source)
title('Source');


figure;
plot(t, i_d_ref, t, i_d_mes)
title('I_d')

hline = findobj(gcf, 'type', 'line');
set(hline(1), 'DisplayName','I_d measured');
set(hline(2), 'DisplayName','I_d reference');
legend1 = legend(gca,'show');
set(legend1,'Location','NorthEast');


figure;
plot(t, i_q_ref, t, i_q_mes)
title('I_q')

hline = findobj(gcf, 'type', 'line');
set(hline(1), 'DisplayName','I_q measured');
set(hline(2), 'DisplayName','I_q reference');
legend2 = legend(gca,'show');
set(legend2,'Location','NorthEast');


%figure;
%plot(t, duty_cycle);
%title('Duty cycle');

figure;
plot(t, u_source, t, 30*u_alpha);
hold on;
title('source and alpha')
plot([0 2], [0 0], 'k')

p = u_source .* i_source + u_source_beta .* i_beta;
q = u_source_beta .* i_source - u_source .* i_beta;
figure; plot(t, p, t, q);
title('active and reactive power');