clear all;
close all;

%% Parameters

%simulation parameter
sim_time = 0.16*5;
sim_maxstep = 1e-4;

%grid parameters:
Uline = 1 * sqrt(2);		%grid line voltage
fnet = 50;							%grid frequency
%fnet = 16 + 2/3;
wnet = 2* pi * fnet;				%grid angle speed

%per unit parameters:
Unom = 400;
Inom = 2.75;
Znom = Unom / Inom;

%ciruit parameters:
Ra = 1;								%load resistance
La = 0.05;                           %load inductance
Ca = 18e-6;							%load capacitance

ra = Ra / Znom;													%load resistance in p.u.
ca = Znom / (wnet*La - 1/(wnet*Ca)) * (wnet*La*Ca - 1 / wnet);	%load capacitance in p.u.
la = La*Ca/ca;													%load inductance in p.u.

%The system in s-plane
Gs = tf([1 0],[La Ra 1/Ca]);

%PWM parameters:
fsw = 2e3;							%switching frequency
Tp = 1/fsw;							%switching period
Tcmd = Tp / 3;						%PWM delay
switching_threshold = 0.05;			%threshold of grid voltage for which switching is turned off in p.u.
%porteur_values = [0 1 0];
porteur_values = [0 1 0];

%regulator paramters;
Kp_d = 0.2;
Ti_d = 10;
Td_d = 0.0;
Kp_q = 0.1;
Ti_q = 10;
Td_q = 0.0;

virtual_resistor = 0.0;

i_damp = 0;

%% references:
%i_d_ref_max = 1.4128;
% i_d_ref = 0.7024;
i_d_ref = 0.5
%k_iqref = -0.0344;
k_iqref = -0.0977;

%% Simulation

sim('Chopper_discreteswitch_closedloop')

%% Plotting

% figure;
% plot(t_plecs, u_source, t_plecs, i_source, [0 sim_time*1.05], [0 0], '--k')
% title('Source');


figure;
plot(t_plecs, u_imp, t_plecs, i_imp, [0 sim_time*1.05], [0 0], '--k')
title('Impedance');


figure;
plot(t, i_d_ref, t_controller, i_d_mes)
title('I_d')

hline = findobj(gcf, 'type', 'line');
set(hline(1), 'DisplayName','I_d measured');
set(hline(2), 'DisplayName','I_d reference');
legend1 = legend(gca,'show');
set(legend1,'Location','NorthEast');


figure;
plot(t, i_q_ref, t_controller, i_q_mes)
title('I_q')

hline = findobj(gcf, 'type', 'line');
set(hline(1), 'DisplayName','I_q measured');
set(hline(2), 'DisplayName','I_q reference');
legend2 = legend(gca,'show');
set(legend2,'Location','NorthEast');

% figure;
% plot(t, i_d_ref, t_controller, i_d_mes, t, i_q_ref, t_controller, i_q_mes, [0 sim_time*1.05],[0 0], '--k')
% title('I_d et I_q')
% 
% hline = findobj(gcf, 'type', 'line');
% set(hline(4), 'DisplayName','I_d measured');
% set(hline(5), 'DisplayName','I_d reference');
% set(hline(2), 'DisplayName','I_q measured');
% set(hline(3), 'DisplayName','I_q reference');
% set(hline(1), 'DisplayName','Y = 0');
% 
% legend3 = legend(gca,'show');
% set(legend3,'Location','SouthEast');

figure;
plot(t_controller, duty_cycle_dq);
title('Duty cycle');

% figure;
% plot(t_controller, u_con, t_plecs, u_source);
% title('Controller set voltage');
% 
% figure;
% plot(t_controller, d_out, t_controller, q_out)

% FFT_info(fft_mes1, 0);
% FFT_info(fft_mes2, 0);

% figure; plot(t_plecs, sign(u_ca).*u_ca.^2*ca/2, t_plecs, sign(i_imp).*i_imp.^2*la/2)