clear all;
close all;

%% Parameters

%simulation parameter
sim_time = 0.6;
sim_maxstep = 1e-6;

%grid parameters:
Uline = 1 * sqrt(2);				%grid line voltage
fnet = 50;							%grid frequency
wnet = 2* pi * fnet;				%grid angle speed

%per unit parameters:
Unom = 50;
Inom = 2.4;
Znom = Unom / Inom;

%ciruit parameters:
Ra = 0.5;								%load resistance
La = 5e-3;                           %load inductance
Ca = 140e-6;							%load capacitance

Rd = 1e-3;							%decoupling / snubber resistance
Cd = 100e-9;							%decoupling / snubber capacitance

%fr = 423Hz
Lf = 2e-3;								%filter inductance
Cf = 47e-6;								%filter capacitance

% component values in p.u.
ra = Ra / Znom;
ca = Znom / (wnet*La - 1/(wnet*Ca)) * (wnet*La*Ca - 1 / wnet);
la = La*Ca/ca;

rd = Rd / Znom;
cd = Cd * Znom;

lf = Lf / Znom;
cf = Cf * Znom;


%The system in s-plane
Gs = tf([1 0],[la ra 1/ca]);

%PWM parameters:
fsw = 2e3;							%switching frequency
Tp = 1/fsw;							%switching period
porteur_values = [0 1 0];
% porteur_values = [-1 1 -1];

d_start = 0.05;

bias = 0.5;

uh = 0*.3;
fh = 6*fnet;
dephase = 0;

uh2 = uh*.3;
fh2 = fh + 2*fnet;
dephase2 = dephase + 0;

uh3 = uh*0;
fh3 = fh2+ 2*fnet;
dephase3 = dephase + 0;

%% Simulation

sim('Chopper_discreteswitch_open_full')

%% Plotting

figure;
plot(t_plecs, u_source, t_plecs, i_source, [0 sim_time*1.05], [0 0], '--k')
title('Source');


figure;
plot(t_plecs, u_imp, t_plecs, i_imp, [0 sim_time*1.05], [0 0], '--k')
title('Impedance');


% figure;
% plot(t_controller, u_con, t_plecs, u_source);
% title('Controller set voltage');


FFT_info(fft_mes1, 0, 0, 44e3);
FFT_info(fft_mes2, 0, 0, 44e3);

% figure; plot(t_plecs, sign(u_ca).*u_ca.^2*ca/2, t_plecs, sign(i_imp).*i_imp.^2*la/2)

% figure;
% plot(t, PWM)
% title('PWM function')